/*
 *
 *      Copyright (C)  Bopp & Reuther Heinrichs Messtechnik 2000 All Rights Reserved.
 *
 *      HART DEVICE DESCRIPTION
 *
 *      Manufacturer:     Bopp & Reuther Heinrichs Messtechnik
 *      Device:           magnetic inductive Transmitter UMF
 *      Univ. Revision:   5
 *      Device Revision:  1
 *      DD Revision:      1
 *      Filename:         UMF.DDL
 *
 *      ---------------------------------
 *
 *      Date:      2000/09/13
 *      Developer: Jens Flegel (ICS GmbH)
 *
 *      ---------------------------------
 *
 *
 */


/*--------------------------- H E A D E R S ----------------------------*/

#include <bi_codes.h>

/*---------------------------- M A C R O S -----------------------------*/

#include <Mecon_magflux_macros.ddl>

/*----------------------- D E C L A R A T I O N S ----------------------*/



// MANUFACTURER 24634, DEVICE_TYPE 57582, DEVICE_REVISION 1, DD_REVISION 1
// MANUFACTURER BOPP_AND_REUTHER_HEINRICHS, DEVICE_TYPE 0xea, DEVICE_REVISION 1, DD_REVISION 1

/******************************************************************************/
/*                                                                            */
/* C o n s t a n t s                                                          */
/*                                                                            */
/******************************************************************************/


/* -------------------------------------------------------------------------- */
/* Dictionary Substitutions                                                   */
/* -------------------------------------------------------------------------- */

//#define alarm_select analog_alarm_code

// ----- includes

#include "SIHASTIDENT01.inc"

// Verlaufskurve
#define  YT1_LABEL	[menu_dialog_display_measure]
#define  YT1_VALUE	flow_rate.DIGITAL_VALUE
#define  YT1_LRV	flow_rate.LOWER_RANGE_VALUE
#define  YT1_URV	flow_rate.UPPER_RANGE_VALUE
#include "SI_YT.inc"


/*
 **********************************************************************
 *                                                                    *
 * Common Tables                                                      *
 *                                                                    *
 **********************************************************************
*/

#include  "Mecon_magflux_Imp_Tables.ddl"

#include  "Mecon_magflux_Imp_Univ7.ddl"

/*
 **********************************************************************
 *                                                                    *
 * Common Practice Commands                                           *
 *                                                                    *
 **********************************************************************
*/
#include  "Mecon_magflux_Imp_Common7.ddl"

/*
 **********************************************************************
 *                                                                    *
 * Redifinition Standard Menu Device Description                      *
 *                                                                    *
 **********************************************************************
*/

// MENU root_menu
MENU Table_Main_Specialist
{
	LABEL "mag-flux M";
	ITEMS
	{
Tab_ident,
Tab_basic_setup,					/* menu */
Tab_aufnehmer,
// Tab_inputs,
Tab_outputs,
Tab_selftest
//		detailed_setup,					/* menu */
	}
}

MENU Table_Main_Maintenance
  {
//	LABEL "UMF";
//	ITEMS
//	{
//		basic_setup,					/* menu */
//		detailed_setup,					/* menu */
//	}
	LABEL "mag-flux M";
	ITEMS
	{
Tab_ident,
Tab_basic_setup,					/* menu */
Tab_aufnehmer_maintenance,
// Tab_inputs,
Tab_outputs,
Tab_selftest
//		detailed_setup,					/* menu */
	}
  }


#include  "Mecon_magflux_Imp_Menu.ddl"

#include  "Mecon_magflux_MainMenu.ddl"

/**********************************************************************
 *                                                                    *
 *      Menues - Submenues                                            *
 *                                                                    *
 **********************************************************************/


MENU   Tab_aufnehmer
  {
  LABEL   "sensor" "|de|Aufnehmer";
  ITEMS
    {
    conf_sensor_const,
conf_sensor_zero,
    conf_sensor_type,
    conf_sensor_inner_width,
    conf_sensor_magn_field_freq,
    conf_sensor_net_freq,
    conf_flow_direction
    }
  }

MENU   Tab_aufnehmer_maintenance
  {
  LABEL   "sensor" "|de|Aufnehmer";
  ITEMS
    {
    conf_sensor_const (READ_ONLY),
conf_sensor_zero (READ_ONLY),
    conf_sensor_type (READ_ONLY),
    conf_sensor_inner_width (READ_ONLY),
    conf_sensor_magn_field_freq (READ_ONLY),
    conf_sensor_net_freq (READ_ONLY),
    conf_flow_direction
    }
  }

MENU   Tab_totalizers
{
	LABEL    "Totalizer|de|Zhler";
	ITEMS
	{
		totalizer_units_choose,
//		reset_totl1,
//		reset_totl2,
//		reset_totlR
	}
}

MENU   				mnu_SV_map
{
	LABEL   		"Map SV-QV|de|Bel. SV-QV";
	ITEMS
	{
		SV_map
		write_device_mode_codes_method

	}
}


MENU   Tab_outputs
{
	LABEL    "Outputs" "|fr|Sorties" "|de|Ausgnge";
	ITEMS
	{
	Tab_current_output,
	Tab_pulse,
	Tab_binary_outputs,
	Tab_totalizers,
	}
}

MENU   Tab_pulse
  {
  LABEL   "Pulse output" "|fr|sortie d'impulsion" "|de|Impulsausgang";
  ITEMS
    {
    pulse_output_choice			(DISPLAY_VALUE),
    pulse_units					(DISPLAY_VALUE)
    pulse_factor				(DISPLAY_VALUE),
    pulse_width					(DISPLAY_VALUE),
    }
  }

/*MENU   Tab_status_output
{
	LABEL    "Status output" "|fr|Etat sortie" "|de|Statusausgang" "|kt|sute-tasu";
	ITEMS
	{
		status_output_active	(DISPLAY_VALUE),
		status_output_relation	(DISPLAY_VALUE)
	}
}*/

MENU   Tab_current_output
  {
  LABEL    "Current output|fr|Courant sortie|de|Stromausgang";
  ITEMS
    {
    current_output_range,
    current_output_alarm
    }
  }

MENU   Tab_binary_outputs
  {
	LABEL    "Binary outputs|de|Binrausgnge";
	ITEMS
	  {
	  binary_output_active_state,
	  binary_output2,
	  binary_output3
	  }
  }

MENU   Tab_binary_input
  {
	LABEL    "Binary input|de|Binreingang";
	ITEMS
	  {
	  binary_input
	  }
  }

MENU   Tab_selftest
  {
	LABEL    "Selftest|de|Selbsttest";
	ITEMS
	{
		self_test_enable         (DISPLAY_VALUE),
		self_test_period         (DISPLAY_VALUE),
		basic_calibration_enable (DISPLAY_VALUE),
		basic_calibration_period (DISPLAY_VALUE),
		check_empty_pipe_enable	 (DISPLAY_VALUE),
		check_empty_pipe_period  (DISPLAY_VALUE)
	}
  }

MENU   mnu_simulation
  {
	LABEL    "Simulation";
	ITEMS
	{
//simulation_abort_method,
		sim_mode,
		sim_Qabs_output, /* float */
                Tab_direct_preset,
		simulation_method,
////		sim_enable
	}
  }

VARIABLE      sim_direct_current_output
  {
	LABEL        "current|de|Strom";
	CLASS   DEVICE;
        CONSTANT_UNIT "mA";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      sim_Qabs_output
  {
	LABEL        "Qabs";
	CLASS   DEVICE;
//unit Qvorgabe???
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".3f";
	}
  }

VARIABLE      sim_pulse
  {
	LABEL        "frequency|de|Frequenz";
	CLASS   DEVICE;
        CONSTANT_UNIT "Hz";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
//		MIN_VALUE   5.0;
//		MAX_VALUE   1100.0;
	}
  }

VARIABLE        sim_direct_bin_out_enable
{
	LABEL          "binary outputs B2, B3|de|Ausgnge B2, B3";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"off|de|aus"  },
		{    0x1, 	"on|de|an"   }
	}
}

VARIABLE        sim_mode
  {
	LABEL          "Preset|de|Vorgabe";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"direct|de|direkt"  },
		{    0x1, 	"Qabs"    }
	}
  }

VARIABLE        sim_enable
{
	LABEL          "Simulation enable|de|Simulation aktiv";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"off|de|aus"   },
		{    0x1, 	"on|de|an"    }
	}
}


MENU Tab_direct_preset
  {
  LABEL    "direct preset|de|direkte Vorgabe";
  ITEMS
	{
		sim_direct_bin_out_enable,
		sim_pulse, /* float */
		sim_direct_current_output /* float */
        }
  }

/**********************************************************************
 *                                                                    *
 *      : Dynamic variables :                                         *
 *                                                                    *
 **********************************************************************/


ARRAY OF COLLECTION transmitter_variables
{
	HELP [transmitter_variable_help];
	ELEMENTS
	{

		0, var_volflow, "vol flow";
		1, var_totalizer1, "totalizer1";
		2, var_velocity,   "velocity";
		3, var_totalizerR, "totalizerR";
		4, var_totalizer2, "totalizer2";
	}
}

ARRAY OF COLLECTION dynamic_variables
{
	HELP [dynamic_variable_help];
	ELEMENTS
	{
		/* Remark: VolFlow appears always as PV */

		PRIMARY, transmitter_variables[0],   [pv], [primary_variable_help];
		SECONDARY, transmitter_variables[1], [sv], [secondary_variable_help];
		TERTIARY,  transmitter_variables[2], [tv], [tertiary_variable_help];
		FOURTH,    transmitter_variables[3], [qv], [fourth_variable_help];


		/*	future:
		PRIMARY, transmitter_variables[0],          [pv], [primary_variable_help];
		SECONDARY, transmitter_variables[secondary_variable_code], [sv], [secondary_variable_help];
		TERTIARY,  transmitter_variables[tertiary_variable_code],  [tv], [tertiary_variable_help];
		FOURTH,    transmitter_variables[fourth_variable_code],    [qv], [fourth_variable_help];
*/
	}
}


/* ----------------------- primary variable ----------------------------------------- */
COLLECTION OF VARIABLE var_volflow
{
	LABEL [pv];
	HELP [primary_variable_help];
	MEMBERS
	{
		/* Measurment */
		DIGITAL_VALUE,		volume_flow_value,		[blank],		[digital_value_help];
		DIGITAL_UNITS,		volume_flow_units,		[units],		[digital_units_help];
		/* Sensor Information */
		SENSOR_UNITS,       volume_flow_units,		[sensor_unit],	[sensor_minspan_unit_help];
		UPPER_SENSOR_LIMIT, sensor_upper_limit,		[usl],			[upper_sensor_limit_help];
		LOWER_SENSOR_LIMIT, sensor_lower_limit,		[lsl],			[lower_sensor_limit_help];
		MINIMUM_SPAN,       sensor_minimum_span,    [minimum_span],	[minimum_span_help];
		DAMPING_VALUE,		sensor_damping_value,	[damping_value],[seconds_damping_value_help];
		/* Input Information */
		PERCENT_RANGE,		input_percent_range,	[percent_of_range], [percent_of_range_help];
		TRANSFER_FUNCTION,	input_transfer_function,[transfer_function],[transfer_function_help];
		RANGE_UNITS,		volume_flow_units,      [range_units],	[range_units_help];
		UPPER_RANGE_VALUE,	upper_range_value,		[urv],			[upper_range_value_help];
		LOWER_RANGE_VALUE,	lower_range_value,		[lrv],			[lower_range_value_help];
		/* Analog Output Information */
		ANALOG_VALUE,		analog_value,			[analog_output_value],[analog_output_help];
		ALARM_CODE,			analog_alarm_code,		[alarm_select],	[alarm_code_help];
		/* Device Information */
		SENSOR_SERIAL_NUMBER, sensor_serial_number,	[sensor_serial_number], [sensor_serial_number_help];
	}
}

/* ----------------------- totalizer1 ----------------------------------------- */
COLLECTION OF VARIABLE var_totalizer1			/*    Zhler1   */
{
	LABEL "totalizer1";
	HELP [secondary_variable_help];
	MEMBERS
	{
		DIGITAL_UNITS,			totalizer_units,			[units],				[digital_units_help];
		DIGITAL_VALUE,			totalizer1,					[blank],				[digital_value_help];
	}
}

/* ----------------------- totalizer2 ----------------------------------------- */
COLLECTION OF VARIABLE var_totalizer2            /*    Zhler2   */
{
	LABEL "totalizer2";
//	HELP [fifth_variable_help];
	MEMBERS
	{
		DIGITAL_UNITS,			totalizer_units,			[units],				[digital_units_help];
		DIGITAL_VALUE,			totalizer2,					[blank],				[digital_value_help];
	}
}

/* ----------------------- totalizer back ----------------------------------------- */
COLLECTION OF VARIABLE var_totalizerR			/*    ZhlerR   */
{
	LABEL "totalizer reverse";
	HELP [fourth_variable_help];
	MEMBERS
	{
		DIGITAL_UNITS,			totalizer_units,			[units],				[digital_units_help];
		DIGITAL_VALUE,			totalizerR,					[blank],				[digital_value_help];
	}
}

/* ----------------------- speed: for the future ----------------------------------------- */

COLLECTION OF VARIABLE var_velocity
{
	LABEL "velocity|de|Geschwindigkeit";
	HELP [tertiary_variable_help];
	/*	HELP [fourth_variable_help]; */
	MEMBERS
	{
		DIGITAL_UNITS,			velocity_unit,	[units],[digital_units_help];
		DIGITAL_VALUE,			velocity,						[blank],				[digital_value_help];
	}
}


/* ----------------------- relations ----------------------------------------- */
UNIT totalizer_unit_relation
{
	totalizer_units:
	totalizer1, totalizer2, totalizerR
}

UNIT velocity_unit_relation
{
	velocity_unit:
	velocity
}

UNIT pv_unit_relation
{
	volume_flow_units:
	volume_flow_value,
	upper_range_value,
	lower_range_value,
	sensor_upper_limit,
	sensor_lower_limit,
	sensor_minimum_span,
sim_Qabs_output
}

REFRESH pv_range_refresh
{
	upper_range_value,
	lower_range_value:
	volume_flow_value
}

/*UNIT pulse_unit_relation
{
	pulse_units:
	pulse_factor
}*/

/* ---------------------------------------------------------- */

/******************************************************************************/
/*                                                                            */
/* M E N U S                                                                  */
/*                                                                            */
/******************************************************************************/
/* -------------------------------------------------------------------------- */
/* Menus of 'root_menu'                                                       */
/* -------------------------------------------------------------------------- */
/* > Menus Basic Settings */

MENU process_data_menu
{
	LABEL  "Process data""|de|Prozedaten";
	ITEMS
	{
		sensor_range_menu,
		Tab_s_input_measwindow,
		sensor_damping_value (DISPLAY_VALUE),
		volume_flow_units (DISPLAY_VALUE),
		totalizer_units (DISPLAY_VALUE),
		transfer_function (DISPLAY_VALUE)
	}
}



MENU sensor_range_menu
{
	LABEL  "Sensor range""|de|Sensorgrenzwerte";
	ITEMS
	{
		sensor_upper_limit (DISPLAY_VALUE),
		sensor_lower_limit (DISPLAY_VALUE)
	}
}



MENU Tab_s_input_measwindow
{
	LABEL  [menu_input_measwindow];
	ITEMS
	{
		sensor_minimum_span (DISPLAY_VALUE),
		lower_range_value (DISPLAY_VALUE),
		upper_range_value (DISPLAY_VALUE)
	}
}


/******************************************************************************/
/*                                                                            */
/* V A R I A B L E S                                                          */
/*                                                                            */
/******************************************************************************/


/* transmitter variables */

/* -------------------------------------  : Parameter UMF  -------------------------------------------------------------- */

VARIABLE      volume_flow_value
{
	LABEL      "Flow|de|Durchflu";
	HANDLING   READ;
	CLASS   DYNAMIC&INPUT;
	HELP   [volume_flow];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".3f";
	}
}

VARIABLE        volume_flow_units
  {
	LABEL          [units];
	CLASS   INPUT;
	HELP   [digital_units_help];
	TYPE   ENUMERATED
	{
		UNITS_CODE (19),
		UNITS_CODE (131),
		UNITS_CODE (28),
		UNITS_CODE (138),
		UNITS_CODE (17),
		UNITS_CODE (24),
		UNITS_CODE (136),
		UNITS_CODE (16),
		UNITS_CODE (22),
		UNITS_CODE (30),
		UNITS_CODE (18),
		UNITS_CODE (137),
UNITS_CODE (75), //kg/h
UNITS_CODE (78)  //t/h
	}
  }

VARIABLE      sensor_upper_limit
{
	LABEL      "USL";
	HANDLING   READ;
	CLASS   CORRECTION;
	HELP   [upper_sensor_limit_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      sensor_lower_limit
{
	LABEL        "LSL";
	HANDLING   READ;
	CLASS   CORRECTION;
	HELP   [lower_sensor_limit_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      sensor_minimum_span
{
	LABEL        [minimum_span];
	HANDLING   READ;
	HELP   [minimum_span_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      sensor_damping_value
{
	LABEL        [damping_value];
	CLASS   INPUT;
	CONSTANT_UNIT   "sec";
	HELP   [seconds_damping_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
		EDIT_FORMAT   ".0f";
	}
}


VARIABLE      input_percent_range
{
	LABEL        [percent_of_range];
	HANDLING   READ;
	CLASS   DYNAMIC&INPUT;
	CONSTANT_UNIT   [Percent];
	HELP   [percent_of_range_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE        input_transfer_function
{
	LABEL          [transfer_function];
	HANDLING   READ;
	CLASS   INPUT;
	HELP   [transfer_function_help];
	TYPE   ENUMERATED
	{
		TRANSFER_FUNCTION_CODE(0)
	}
}

VARIABLE      upper_range_value
{
	LABEL        [urv];
	CLASS   INPUT;
	HELP   [upper_range_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   "8.2f";
	}
}

VARIABLE      lower_range_value
{
	LABEL        [lrv];
	CLASS   INPUT;
	HELP   [lower_range_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   "8.2f";
	}
}


VARIABLE      analog_value
{
	LABEL        [pv_analog_value];
	CLASS   ANALOG_OUTPUT&DYNAMIC;
	CONSTANT_UNIT   "mA";
	HELP   [analog_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

/* analog_units */
VARIABLE        analog_alarm_code
{
	LABEL          [alarm_select];
	CLASS   ANALOG_OUTPUT;
	HELP   [alarm_code_help];
	TYPE   ENUMERATED
	{
		ALARM_SELECTION_CODE(0),
		ALARM_SELECTION_CODE(251)
	}
}

VARIABLE      sensor_serial_number
{
	LABEL        [sensor_serial_number];
	CLASS   DEVICE;
	HELP   [sensor_serial_number_help];
	TYPE    UNSIGNED_INTEGER(3)
	{
		DISPLAY_FORMAT   "7d";
	}
}



VARIABLE      totalizer_para
  {
	LABEL        "Parameter totalizer|de|Zhlerparameter";
	CLASS   LOCAL;
	TYPE    UNSIGNED_INTEGER(2);
  }

VARIABLE      blocktransfer
  {
	CLASS   LOCAL;
	TYPE    UNSIGNED_INTEGER(2);
  }

VARIABLE      totalizer1
{
	LABEL        "Totalizer1|de|Zhler1";
	HANDLING   READ;
	CLASS   COMPUTATION&DYNAMIC;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      totalizer2
{
	LABEL        "Totalizer2|de|Zhler2";
	HANDLING   READ;
	CLASS   COMPUTATION&DYNAMIC;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      totalizerR
{
	LABEL        "TotalizerR|de|ZhlerR";
	HANDLING   READ;
	CLASS   COMPUTATION&DYNAMIC;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

/* totalizerD (geplant) */
VARIABLE      velocity
{
	LABEL        "Velocity|de|Geschwindigkeit";
	HANDLING   READ;
	CLASS   COMPUTATION&DYNAMIC;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      dichte
{
	LABEL        "Density|de|Dichte";
	CLASS   DEVICE;
	CONSTANT_UNIT   "g/l";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}

VARIABLE      low_flow_cutoff
{
	LABEL        "Low flow cutoff|de|Schleichmenge";
	CLASS   DEVICE;
	CONSTANT_UNIT   "%";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}

VARIABLE      low_flow_cutoff_hyst
{
	LABEL        "Low Flow Cut Off Hysteresis|de|Schleichmengen-Hysterese";
	CLASS   DEVICE;
	CONSTANT_UNIT   "%";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}

VARIABLE      flow_limit_min
{
	LABEL       			"Setpoint MIN" "|de|MIN-Grenzwert";
	CLASS   DEVICE;
	CONSTANT_UNIT   "%";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}

VARIABLE      flow_limit_max
{
	LABEL       			"Setpoint MAX" "|de|MAX-Grenzwert";
	CLASS   DEVICE;
	CONSTANT_UNIT   "%";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}

VARIABLE      flow_limit_hyst
{
	LABEL	"Setpoint hysteresis" "|de|Grenzwert-Hysterese";
	CLASS   DEVICE;
	CONSTANT_UNIT   "%";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}


VARIABLE      close_time
{
	LABEL        "Close Time|de|Verschluzeit";
	CLASS   DEVICE;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".3f";
	}
}


VARIABLE      conf_sensor_const
{
	LABEL        "CFH|de|CFH";
	CLASS   DEVICE;

	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".7f";
	}
}

VARIABLE      conf_sensor_zero
{
	LABEL        "ZPH|de|ZPH";
	CLASS   DEVICE;

	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".7f";
	}
}

VARIABLE      conf_sensor_inner_width
{
	LABEL        "Nominal width|de|Nennweite";
	CLASS   DEVICE;
	CONSTANT_UNIT   [mm];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}


VARIABLE      sw_version
{
	LABEL        "Firmware Revision|de|Software-Version";
	CLASS   DEVICE;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE        conf_sensor_type
{
	LABEL          "Sensor type|de|Aufnehmertyp";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"TYP A"      },
		{    0x1, 	"TYP S"     },
		{    0x2, 	"TYP F5"      },
		{    0x3, 	"MIS"  }
	}
}

VARIABLE        conf_sensor_magn_field_freq
{
	LABEL          "Excitation Frequency|de|Magnetfeldtaktfrequenz";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"1.56 Hz"   },
		{    0x1, 	"3.125 Hz"  },
		{    0x2, 	"6.25 Hz"   },
		{    0x3, 	"12.5 Hz"   },
		{    0x4, 	"25 Hz"     }
	}
}

VARIABLE        conf_sensor_net_freq
  {
	LABEL          "Mains frequency|de|Netzfrequenz";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"50 Hz"   },
		{    0x1, 	"60 Hz"   }
	}
  }

VARIABLE        conf_disp_language
{
	LABEL   "Language of local Display|fr|Language|de|Sprache der Vor-Ort-Anzeige";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"german" "|de|Deutsch"   },
		{    0x1, 	"english" "|de|Englisch"  },
	//	{    0x2, 	[french]   }
	}
}

VARIABLE        conf_disp_initial
{
	LABEL          "Display mode on startup|de|Anzeige bei Einschalten";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"Volume flow QV|de|Volumendurchflu QV"                },
		{    0x1, 	"Forward totalizer 1|de|Zhler 1 Vorflu"             },
		{    0x2, 	"Forward totalizer 2|de|Zhler 2 Vorflu"             },
		{    0x3, 	"Reverse totalizer|de|Zhler Rckflu"     },
		{    0x4, 	"Velocity|de|Geschwindigkeit"      },
		{    0x5, 	"QVabs+QVrel|de|QVabs+QVrel"    },
		{    0x6, 	"QV+totalizer 1|de|QV+Zhler 1"        },
		{    0x7, 	"QV+totalizer 2|de|QV+Zhler 2 "       },
		{    0x8, 	"QV+velocity|de|QV+Geschwindigkeit"        },
		{    0x9, 	"test field|de|Prffeld"        },
{    0xA, 	"Mass flow QM|de|Massedurchflu QM"                }
	}
}

/* Bem.: SV-Map: vorlufig nur Read bis Gertenderung */
VARIABLE        SV_map
{
	LABEL          "Map SV-QV|de|SV Zuweisung";
	HANDLING   READ;
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"SV=spd TV=To1 QV=ToR|de|SV=Geschwind. TV=Zhler1  QV=ZhlerR"   },
		{    0x1, 	"SV=To1 TV=To2 QV=ToR|de|SV=Zhler1    TV=Zhler2  QV=ZhlerR"   }
	}
}

VARIABLE        totalizer_units
{
	LABEL          "Totalizer Unit|de|Einheit Zhler";
	CLASS   DEVICE;
	TYPE   ENUMERATED
	{
		UNITS_CODE (43),
		UNITS_CODE (41),
		UNITS_CODE (40),
		UNITS_CODE (42),
UNITS_CODE (61), //kg
UNITS_CODE (62)  //t

//		UNITS_CODE (112)
	}
}

VARIABLE        velocity_unit
{
	LABEL          "Velocity|de|Geschwindigkeit";
	CLASS   DEVICE;
	TYPE   ENUMERATED
	{
		UNITS_CODE (21),
		UNITS_CODE (43),
		UNITS_CODE (41),
		UNITS_CODE (40),
		UNITS_CODE (42),
		UNITS_CODE (61), //kg
		UNITS_CODE (62)  //t

	}
}

VARIABLE        totalizer_units_choose
  {
	LABEL          "Unit|de|Einheit";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		UNITS_CODE (43),
		UNITS_CODE (41),
		UNITS_CODE (40),
		UNITS_CODE (42),
//		UNITS_CODE (112)
UNITS_CODE (61), //kg
UNITS_CODE (62)  //t
	}
  }

VARIABLE        current_output_range
  {
  LABEL          "Range|fr|chelle|de|Bereich";
  CLASS   DEVICE;
  TYPE   ENUMERATED(2)
    {
	{0,"0-21.6 mA"  },
	{1,"4-21.6 mA"  },
	{2,"4-20.4 mA"  }
    }
  }

VARIABLE        current_output_alarm
  {
	LABEL          "Alarm";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"< 3.8 mA"     },
		{    0x1, 	"> 22 mA"    },
		{    0x2, 	"unused|de|unbenutzt"   }
	}
  }

VARIABLE        conf_flow_direction
  {
  LABEL  "Flow direction" "|de|Durchflurichtung";
  CLASS   DEVICE;
  TYPE   ENUMERATED(2)
    {
		{   	0, 	"forward" "|de|vorwrts"  },
		{   	1, 	"reverse" "|de|rckwrts"  },
		{	2, 	"forward&reverse" "|de|vor&rck"  }
    }
  }

VARIABLE        binary_output2
  {
	LABEL          "Binary Output 2 assignment|de|Zuordnung Binrausgang 2";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"Forward flow|de|Vorflu"  },
		{    0x1, 	"Reverse flow|de|Rckflu"  },
		{    0x2, 	"MIN"     },
		{    0x3, 	"MAX"     },
		{    0x4, 	"Alarm"       },
		{    0x5, 	"IMP2 90"    }
	}
  }

VARIABLE        binary_output3
  {
	LABEL          "Binary Output 3 assignment|de|Zuordnung Binrausgang 3";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"Forward flow|de|Vorflu"  },
		{    0x1, 	"Reverse flow|de|Rckflu"  },
		{    0x2, 	"MIN"     },
		{    0x3, 	"MAX"     },
		{    0x4, 	"Alarm"       },
		{    0x5, 	"not available|de|nicht vorhanden"  }
	}
}

VARIABLE        binary_input
{
	LABEL          "Binary input assignment|de|Zuordnung Binreingang";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"Reset totalizer 1|de|Zhler 1 rcksetzen"  },
		{    0x1, 	"Reset errors|de|Fehler rcksetzen"   },
		{    0x2, 	"Zero calibration|de|Nullpunkt kalibrieren"    },
		{    0x3, 	"not available|de|nicht vorhanden"     }
	}
}

VARIABLE        binary_output_active_state
  {
	LABEL	"Active state" "|de|Aktiver Zustand";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"closed|de|geschlossen"  },
		{    0x1, 	"opened|de|geffnet"     }
	}
  }

VARIABLE        pulse_factor
  {
  LABEL          "pulse value: 1 pulse per" "|fr|Fact" "|de|Wertigkeit: 1 Impuls pro";
  CLASS   CORRECTION;
CONSTANT_UNIT  SELECT(pulse_units)
                 {
		 CASE 61: "kg";
		 CASE 62: "t";
		 CASE 43: [CuMtr];
		 CASE 41: "L";
		 CASE 40: "gal";
	         CASE 42: "Impgal";
                 }

	TYPE   ENUMERATED(2)
	{
/*		{   	69, "0.001"  },
		{   	68, "0.01"  },
		{   	67, "0.1"  },
		{   	66, "1.0"  },
		{   	65, "10.0"  },
		{   	64, "100.0"  }*/

		{    0x0, 	"0.001"  },
		{    0x1, 	"0.01"   },
		{    0x2, 	"0.1"    },
		{    0x3, 	"1.0"    },
		{    0x4, 	"10.0"   },
		{    0x5, 	"100.0"  }
		
	}
  }

VARIABLE      pulse_width
{
	LABEL        "Pulse width|de|Impulsbreite";
	CLASS   DEVICE;
        CONSTANT_UNIT "msec";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
	}
}

VARIABLE        pulse_units
  {
  LABEL          [units];
  CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		UNITS_CODE (43),
		UNITS_CODE (41),
		UNITS_CODE (40),
		UNITS_CODE (42),
//		UNITS_CODE (112)
UNITS_CODE (61), //kg
UNITS_CODE (62)  //t
	}
  }


/* pulse_phase_IMP2 */
VARIABLE        pulse_output_choice
  {
  LABEL 	"Output of" "|de|Ausgabe von";
  CLASS   CORRECTION;
  TYPE   ENUMERATED(2)
    {
      {   0x0, 	"pulses" "|fr|Impulsion""|de|Impulsen"   },
      {   0x1, 	"frequency" "|fr|Frquence" "|de|Frequenz"   }
    }
  }


/*??? MIS_MID_choice */



/* ----- configuration page Selbsttest ----- */
VARIABLE        self_test_enable
{
	LABEL          "Self test|de|Selbsttest";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"off|de|aus"  },
		{    0x1, 	"on|de|an"   }
	}
}

VARIABLE        basic_calibration_enable
{
	LABEL          "Reference calibration|de|Grundabgleich";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"off|de|aus"  },
		{    0x1, 	"on|de|an"   }
	}
}

VARIABLE        check_empty_pipe_enable
{
	LABEL          "Empty pipe detection|de|Leerrohrprfung";
	CLASS   DEVICE;
	TYPE   ENUMERATED(2)
	{
		{    0x0, 	"off|de|aus"  },
		{    0x1, 	"on|de|an"   }
	}
}

VARIABLE      self_test_period
  {
	LABEL        "Self test periode STP|de|Selbsttest Periode STP";
	CLASS   DEVICE;
	CONSTANT_UNIT   "sec";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
	}
  }

VARIABLE      basic_calibration_period
  {
	LABEL        "Reference calibration periode GAP|de|Grundabgleich Periode GAP";
	CLASS   DEVICE;
	CONSTANT_UNIT   "STP";
        TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
	}
}

VARIABLE      check_empty_pipe_period
{
	LABEL        "Empty pipe detection periode|de|Leerrohrprfung Periode";
	CLASS   DEVICE;
	CONSTANT_UNIT   "Min";
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
	}
}


/* ------------------------------  : ParameterUMF  Ende -------------------------------------- */









































































































/*********************************************************************
*                                                                    *
*      Commands                                                      *
*                                                                    *
*********************************************************************/

/* ------------------------------------- : Commands UMF ----------------------------------------------- */
COMMAND  write_blocktransfer
{
	NUMBER   128;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
blocktransfer
		}
		REPLY
		{
			response_code, device_status,
			blocktransfer
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------------------*/
COMMAND write_dichte
{
	NUMBER   145;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			dichte
		}
		REPLY
		{
			response_code, device_status,
			dichte
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_dichte
{
	NUMBER   146;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			dichte
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*---------------------------------------------*/
COMMAND     write_low_flow_cutoff
{
	NUMBER   129;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			low_flow_cutoff
		}
		REPLY
		{
			response_code, device_status,
			low_flow_cutoff
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_low_flow_cutoff
{
	NUMBER   130;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			low_flow_cutoff
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/
COMMAND     write_low_flow_cutoff_hyst
{
	NUMBER   131;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			low_flow_cutoff_hyst
		}
		REPLY
		{
			response_code, device_status,
			low_flow_cutoff_hyst
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_low_flow_cutoff_hyst
{
	NUMBER   132;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			low_flow_cutoff_hyst
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_flow_limit_min
{
	NUMBER   133;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			flow_limit_min
		}
		REPLY
		{
			response_code, device_status,
			flow_limit_min
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_flow_limit_min
{
	NUMBER   134;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			flow_limit_min
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_flow_limit_max
{
	NUMBER   135;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			flow_limit_max
		}
		REPLY
		{
			response_code, device_status,
			flow_limit_max
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		\
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_flow_limit_max
{
	NUMBER   136;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			flow_limit_max
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_flow_limit_hyst
{
	NUMBER   137;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			flow_limit_hyst
		}
		REPLY
		{
			response_code, device_status,
			flow_limit_hyst
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_flow_limit_hyst
{
	NUMBER   138;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			flow_limit_hyst
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}


/*-------------------------------*/

COMMAND     write_check_empty_pipe_period
{
	NUMBER   139;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			check_empty_pipe_period
		}
		REPLY
		{
			response_code, device_status,
			check_empty_pipe_period
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_check_empty_pipe_period
{
	NUMBER   140;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			check_empty_pipe_period
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_self_test_period
{
	NUMBER   141;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			self_test_period
		}
		REPLY
		{
			response_code, device_status,
			self_test_period
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_self_test_period
{
	NUMBER   142;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			self_test_period
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_basic_calibration_period
{
	NUMBER   143;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			basic_calibration_period
		}
		REPLY
		{
			response_code, device_status,
			basic_calibration_period
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_basic_calibration_period
{
	NUMBER   144;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			basic_calibration_period
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}


/*-------------------------------*/

COMMAND     write_close_time
{
	NUMBER   145;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			close_time
		}
		REPLY
		{
			response_code, device_status,
			close_time
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_close_time
{
	NUMBER   146;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			close_time
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_sim_pulse
{
	NUMBER   147;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sim_pulse
		}
		REPLY
		{
			response_code, device_status,
			sim_pulse
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_sim_pulse
{
	NUMBER   148;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			sim_pulse
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_conf_sensor_const
{
	NUMBER   149;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_sensor_const
		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_const
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_conf_sensor_const
{
	NUMBER   150;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_const
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_conf_sensor_inner_width
{
	NUMBER   151;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_sensor_inner_width
		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_inner_width
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_conf_sensor_inner_width
{
	NUMBER   152;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_inner_width
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_sim_direct_current_output
{
	NUMBER   153;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sim_direct_current_output
		}
		REPLY
		{
			response_code, device_status,
			sim_direct_current_output
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_sim_direct_current_output
{
	NUMBER   154;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			sim_direct_current_output
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_sim_Qabs_output
{
	NUMBER   155;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sim_Qabs_output
		}
		REPLY
		{
			response_code, device_status,
			sim_Qabs_output
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_sim_Qabs_output
{
	NUMBER   156;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			sim_Qabs_output
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     read_sw_version
{
	NUMBER   158;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			sw_version
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}

/*-------------------------------*/

COMMAND     write_pulse_width
{
	NUMBER   159;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pulse_width
		}
		REPLY
		{
			response_code, device_status,
			pulse_width
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}
COMMAND     read_pulse_width
{
	NUMBER   160;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			pulse_width
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		3, DATA_ENTRY_ERROR, 	[passed_parameter_too_large];
		4, DATA_ENTRY_ERROR, 	[passed_parameter_too_small];
	}
}




/* ================= Auswahlkommandos ============================== */
/*-------------------------------*/

COMMAND     write_conf_disp_language
{
	NUMBER   180;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_disp_language
		}
		REPLY
		{
			response_code, device_status,
			conf_disp_language
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_conf_disp_language
{
	NUMBER   181;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_disp_language
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_conf_disp_initial
{
	NUMBER   182;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_disp_initial
		}
		REPLY
		{
			response_code, device_status,
			conf_disp_initial
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_conf_disp_initial
{
	NUMBER   183;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_disp_initial
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_SV_map
{
	NUMBER   184;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			SV_map
		}
		REPLY
		{
			response_code, device_status,
			SV_map
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_SV_map
{
	NUMBER   185;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			SV_map
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_totalizer_units
{
	NUMBER   186;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		totalizer_units_choose
		}
		REPLY
		{
		response_code, device_status,
		totalizer_units_choose
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_totalizer_units
{
	NUMBER   187;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
		response_code, device_status,
		totalizer_units_choose
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     reset_totalizer1
{
	NUMBER   188;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			totalizer_para
		}
		REPLY
		{
			response_code, device_status,
			totalizer_para
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     reset_totalizer2
{
	NUMBER   190;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			totalizer_para
		}
		REPLY
		{
			response_code, device_status,
			totalizer_para
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     reset_totalizerR
{
	NUMBER   192;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			totalizer_para
		}
		REPLY
		{
			response_code, device_status,
			totalizer_para
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     reset_totalizerD
{
	NUMBER   194;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			totalizer_para
		}
		REPLY
		{
			response_code, device_status,
			totalizer_para
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     zero_calibrate
{
	NUMBER   196;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			totalizer_para
		}
		REPLY
		{
			response_code, device_status,
			totalizer_para
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_current_output_range
{
	NUMBER   198;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			current_output_range
		}
		REPLY
		{
			response_code, device_status,
			current_output_range
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_current_output_range
{
	NUMBER   199;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			current_output_range
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_current_output_alarm
{
	NUMBER   200;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			current_output_alarm
		}
		REPLY
		{
			response_code, device_status,
			current_output_alarm
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_current_output_alarm
{
	NUMBER   201;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			current_output_alarm
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_conf_flow_direction
{
	NUMBER   202;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_flow_direction
		}
		REPLY
		{
			response_code, device_status,
			conf_flow_direction
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_conf_flow_direction
{
	NUMBER   203;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_flow_direction
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}


/*-------------------------------*/

COMMAND     write_binary_output2
{
	NUMBER   204;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			binary_output2
		}
		REPLY
		{
			response_code, device_status,
			binary_output2
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_binary_output2
{
	NUMBER   205;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			binary_output2
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_binary_output3
{
	NUMBER   206;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			binary_output3
		}
		REPLY
		{
			response_code, device_status,
			binary_output3
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_binary_output3
{
	NUMBER   207;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			binary_output3
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_binary_input
{
	NUMBER   208;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			binary_input
		}
		REPLY
		{
			response_code, device_status,
			binary_input
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_binary_input
{
	NUMBER   209;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			binary_input
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_binary_output_active_state
{
	NUMBER   210;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			binary_output_active_state
		}
		REPLY
		{
			response_code, device_status,
			binary_output_active_state
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_binary_output_active_state
{
	NUMBER   211;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			binary_output_active_state
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
/*-------------------------------*/

COMMAND     write_pulse_factor
{
	NUMBER   212;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pulse_factor
		}
		REPLY
		{
			response_code, device_status,
			pulse_factor
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_pulse_factor
{
	NUMBER   213;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			pulse_factor
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_pulse_units
{
	NUMBER   214;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pulse_units
		}
		REPLY
		{
			response_code, device_status,
			pulse_units
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_pulse_units
{
	NUMBER   215;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			pulse_units
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_self_test_enable
{
	NUMBER   216;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			self_test_enable
		}
		REPLY
		{
			response_code, device_status,
			self_test_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_self_test_enable
{
	NUMBER   217;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			self_test_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_pulse_output_choice
{
	NUMBER   218;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			pulse_output_choice
		}
		REPLY
		{
			response_code, device_status,
			pulse_output_choice
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_pulse_output_choice
{
	NUMBER   219;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			pulse_output_choice
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}


/*-------------------------------*/

COMMAND     write_conf_sensor_type
{
	NUMBER   220;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_sensor_type
		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_type
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_conf_sensor_type
{
	NUMBER   221;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_type
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_conf_sensor_magn_field_freq
{
	NUMBER   222;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_sensor_magn_field_freq
		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_magn_field_freq
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_conf_sensor_magn_field_freq
{
	NUMBER   223;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_magn_field_freq
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_conf_sensor_net_freq
{
	NUMBER   224;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			conf_sensor_net_freq
		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_net_freq
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_SW_conf_sensor_net_freq
{
	NUMBER   225;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			conf_sensor_net_freq
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
/*-------------------------------*/

COMMAND     write_check_empty_pipe_enable
{
	NUMBER   226;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			check_empty_pipe_enable
		}
		REPLY
		{
			response_code, device_status,
			check_empty_pipe_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_check_empty_pipe_enable
{
	NUMBER   227;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			check_empty_pipe_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}


/*-------------------------------*/

COMMAND     write_sim_enable
{
	NUMBER   228;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sim_enable
		}
		REPLY
		{
			response_code, device_status,
			sim_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_sim_mode
{
	NUMBER   230;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sim_mode
		}
		REPLY
		{
			response_code, device_status,
			sim_mode
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_sim_mode
{
	NUMBER   231;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			sim_mode
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_sim_direct_bin_out_enable
{
	NUMBER   232;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			sim_direct_bin_out_enable
		}
		REPLY
		{
			response_code, device_status,
			sim_direct_bin_out_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_sim_direct_bin_out_enable
{
	NUMBER   233;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			sim_direct_bin_out_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/*-------------------------------*/

COMMAND     write_basic_calibration_enable
{
	NUMBER   234;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			basic_calibration_enable
		}
		REPLY
		{
			response_code, device_status,
			basic_calibration_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}
COMMAND     read_basic_calibration_enable
{
	NUMBER   235;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			basic_calibration_enable
		}
	}
	RESPONSE_CODES
	{
		0, SUCCESS, 	[no_command_specific_errors];
		12, DATA_ENTRY_ERROR, [invalid_selection];
	}
}

/* ------------------------------------- : Commands Ende --------------------------------------- */
/*********************************************************************
*                                                                    *
*      Methods                                                       *
*                                                                    *
*********************************************************************/
METHOD block_transfer_start
{
	DEFINITION
	{
		char status[3];
		char disp_string1[60];
		int slen1;

		slen1 =60;

		IGNORE_ALL_RESPONSE_CODES();
		XMTR_IGNORE_ALL_RESPONSE_CODES();
		IGNORE_ALL_DEVICE_STATUS();
		XMTR_IGNORE_ALL_DEVICE_STATUS();
//		RETRY_ON_RESPONSE_CODE(DEVICE_BUSY);/* -change- */
//		SET_NUMBER_OF_RETRIES(10);					/* - - - - */

		assign_int(blocktransfer,1); /*start*/
//		get_dictionary_string(making_changes_permanent,disp_string1,slen1);
//		DELAY(3,disp_string1);
		send(128,status);
		if (status[STATUS_RESPONSE_CODE])
		 {
		 display_response_status(128,status[STATUS_RESPONSE_CODE]);
		 get_dictionary_string(previous_err_seen_brn_eeprom,disp_string1,slen1);
		 ACKNOWLEDGE(disp_string1);
		 }
	}
}

METHOD block_transfer_stop
{
	DEFINITION
	{
		char status[3];
		char disp_string1[60];
		int slen1;

		slen1 =60;

		IGNORE_ALL_RESPONSE_CODES();
		XMTR_IGNORE_ALL_RESPONSE_CODES();
		IGNORE_ALL_DEVICE_STATUS();
		XMTR_IGNORE_ALL_DEVICE_STATUS();
//		RETRY_ON_RESPONSE_CODE(DEVICE_BUSY);/* -change- */
//		SET_NUMBER_OF_RETRIES(10);					/* - - - - */

		assign_int(blocktransfer,0); /*stop&save*/
		get_dictionary_string(making_changes_permanent,disp_string1,slen1);
		DELAY(3,disp_string1);
		send(128,status);
		if (status[STATUS_RESPONSE_CODE])
		 {
		 display_response_status(128,status[STATUS_RESPONSE_CODE]);
		 get_dictionary_string(previous_err_seen_brn_eeprom,disp_string1,slen1);
		 ACKNOWLEDGE(disp_string1);
		 }
	}
}


METHOD  reset_totl1
{
	LABEL  "Reset totalizer 1|de|Zhler 1 rcksetzen";
	DEFINITION
	{
		char status[STATUS_SIZE];
		IGNORE_ALL_RESPONSE_CODES();
//		ACKNOWLEDGE("Really reset totalizer 1 ?|de|Zhler 1 wirklich rcksetzen?");
		iassign(totalizer_para, 1);
		send(188, status);
		if (status[STATUS_RESPONSE_CODE]) {
			display_response_status(188, status[STATUS_RESPONSE_CODE]);
		}
		else {
			DELAY(2,"OK");
		}
	}
}

METHOD  reset_totl2
{
	LABEL  "Reset totalizer 2|de|Zhler 2 rcksetzen";
	DEFINITION
	{
		char status[STATUS_SIZE];
		IGNORE_ALL_RESPONSE_CODES();
//		ACKNOWLEDGE("Really reset totalizer 2 ?|de|Zhler 2 wirklich rcksetzen?");
		iassign(totalizer_para, 1);
		send(190, status);
		if (status[STATUS_RESPONSE_CODE]) {
			display_response_status(190, status[STATUS_RESPONSE_CODE]);
		}
		else {
			DELAY(1,"OK");
		}
	}
}

METHOD  reset_totlR
{
	LABEL  "Reset totalizer R|de|Zhler R rcksetzen";
	DEFINITION
	{
		char status[STATUS_SIZE];
		IGNORE_ALL_RESPONSE_CODES();
//		ACKNOWLEDGE("Really reset totalizer R ?|de|Zhler R wirklich rcksetzen?");
		iassign(totalizer_para, 1);
		send(192, status);
		if (status[STATUS_RESPONSE_CODE]) {
			display_response_status(192, status[STATUS_RESPONSE_CODE]);
		}
		else {
			DELAY(1,"OK");
		}
	}
}

METHOD  zero_trim
{
	LABEL  "Zero trim|de|Nullpunktabgleich";
	DEFINITION
	{
		char status[STATUS_SIZE];
		IGNORE_ALL_RESPONSE_CODES();
//		ACKNOWLEDGE("Press OK to perform zero trim !" "|de|Nullpunktabgleich mit OK starten");
		iassign(totalizer_para, 1);
		send(196, status);
		if (status[STATUS_RESPONSE_CODE]) {
			display_response_status(196, status[STATUS_RESPONSE_CODE]);
		}
		else {
			DELAY(1,"OK");
		}
	}
}

METHOD master_reset_method
{
	LABEL "Master reset|de|Gert rcksetzen";
	DEFINITION
	{
		char status[STATUS_SIZE];
		IGNORE_ALL_RESPONSE_CODES();
		ACKNOWLEDGE("Press OK to perform master reset|de|Gert rcksetzen mit OK");
		send(42, status);
		if (status[STATUS_RESPONSE_CODE]) {
			display_response_status(42, status[STATUS_RESPONSE_CODE]);
		}
		else {
			DELAY(2,"OK");
		}
	}
}

METHOD simulation_method
{
	LABEL   "Start simulation|de|Simulation starten";
	CLASS CORRECTION;
	DEFINITION
	{
//		add_abort_method(simulation_abort_method);
		iassign(sim_enable, 1);
		send_command(228);
PUT_MESSAGE("Simulation is running\n\push \"OK\" to terminate" "|de|Simulation luft\n\nMit \"OK\" beenden");
		iassign(sim_enable, 0);
		send_command(228);
	}
}

METHOD simulation_abort_method
{
	LABEL   "Stop simulation|de|Simulation beenden";
	DEFINITION
	{
		char status[STATUS_SIZE];
		IGNORE_ALL_RESPONSE_CODES();
		XMTR_IGNORE_ALL_RESPONSE_CODES();
		IGNORE_ALL_DEVICE_STATUS();
		XMTR_IGNORE_ALL_DEVICE_STATUS();
		iassign(sim_enable, 0);
		do {
			send(228,status);
		} while(status[STATUS_RESPONSE_CODE]==0x20);
		DELAY(3,"** Simulation off **");
	}
}


/* SV-Mapping: template: DIMF */
METHOD write_device_mode_codes_method
{
	LABEL "Write PV-QV";

	DEFINITION
	{
		long ids[4];

		ids[0] = VARID(primary_variable_code);
		ids[1] = VARID(secondary_variable_code);
		ids[2] = VARID(tertiary_variable_code);
		ids[3] = VARID(fourth_variable_code);

		/*
    GET_DEV_VAR_VALUE("PV code", primary_variable_code);
    GET_DEV_VAR_VALUE("SV code", secondary_variable_code);
    GET_DEV_VAR_VALUE("TV code", tertiary_variable_code);
    GET_DEV_VAR_VALUE("QV code", fourth_variable_code);
*/

		iassign(primary_variable_code, 0);
		iassign(secondary_variable_code, 1);
		iassign(tertiary_variable_code, 2);
		iassign(fourth_variable_code, 3);

		ivar_value(secondary_variable_code);    /* Gegenstck   */

		acknowledge("PV-Code: %{0} \nSV-Code: %{1}\nTV-Code: %{2}\nQV-Code: %{3}", ids);

		/*     send_command(51); */   /* bei UMF nicht in dieser Form in Gert speichern */

	}
}

//in umf selbst: wenn nur masseeinheit als unit gewhlt wird, mte alles mgliche umgerechnet werden, da einheiten an pv hngen
//was gibt der umf bei simu qv als qm aus?
//usl,lsl,simulation_abort_method auch umc2, bringt das was, was soll add_abort...
//messwertanzeige, wenn pv in kg/h und sonst alles in m3/h ?

//ak umc2 noch

//be: umf ist durcheinander, spalt einstellg
//was sind systemfehler ???
//be alles scheint doppelt so lange zu dauern bitte wrten, 1 minute
//spulenstrom geht nicht weg, wenn test grundabgl ausgeschaltet wird
//werknummer 0 default
//simu default 6 hz! in umf

//be nach englisch>deutsch spinnt oberflche
//be test springt nach reset
//rottmann 0571/ 830 1938    fax.1871
/*abb
schillerstr 72
32425 minden he.freye
martin.freye@de.abb.com*/
//umf1 zusammenstellung v statt z2

//aBB
//136,E /h
//161, entwickler
//default f. anzahl resp preams funktioniert nicht
//min/max simu imp
//m3 hochsetzen